@@ -1,13 +1,11 @@
 package GeoIP2::Error::HTTP;
 {
-  $GeoIP2::Error::HTTP::VERSION = '0.0200';
+  $GeoIP2::Error::HTTP::VERSION = '0.0300';
 }
 
 use strict;
 use warnings;
 
-use GeoIP2::Types qw( Str );
-
 use Moo;
 
 with 'GeoIP2::Role::Error::HTTP';
@@ -28,7 +26,7 @@ GeoIP2::Error::HTTP - An HTTP transport error
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -36,6 +34,7 @@ version 0.0200
 
   use GeoIP2::WebService::Client;
   use Scalar::Util qw( blessed );
+  use Try::Tiny;
 
   my $client = GeoIP2::WebService::Client->new(
       user_id     => 42,
@@ -77,7 +76,7 @@ Returns the URI which gave the HTTP error.
 
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>
+Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
