@@ -1,6 +1,6 @@
 package GeoIP2::Model::CityISPOrg;
 {
-  $GeoIP2::Model::CityISPOrg::VERSION = '0.0200';
+  $GeoIP2::Model::CityISPOrg::VERSION = '0.0300';
 }
 
 use strict;
@@ -11,11 +11,9 @@ use Sub::Quote qw( quote_sub );
 
 use Moo;
 
-with 'GeoIP2::Role::Model';
+with 'GeoIP2::Role::Model', 'GeoIP2::Role::Model::HasSubdivisions';
 
-__PACKAGE__->_define_attributes_for_keys(
-    qw( city continent country location registered_country represented_country traits )
-);
+__PACKAGE__->_define_attributes_for_keys( __PACKAGE__->_all_record_names() );
 
 1;
 
@@ -31,7 +29,7 @@ GeoIP2::Model::CityISPOrg - Model class for the GeoIP2 Precision City/ISP/Org en
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -84,6 +82,16 @@ believes the IP is located in.
 Returns a L<GeoIP2::Record::Location> object representing country data for the
 requested IP address.
 
+=head2 $city_isp_org->maxmind()
+
+Returns a L<GeoIP2::Record::MaxMind> object representing data about your
+MaxMind account.
+
+=head2 $city_isp_org->postal()
+
+Returns a L<GeoIP2::Record::Postal> object representing postal code data for
+the requested IP address.
+
 =head2 $city_isp_org->registered_country()
 
 Returns a L<GeoIP2::Record::Country> object representing the registered
@@ -91,13 +99,13 @@ country data for the requested IP address. This record represents the country
 where the ISP has registered a given IP block in and may differ from the
 user's country.
 
-=head2 $omni->represented_country()
+=head2 $city_isp_org->represented_country()
 
 Returns a L<GeoIP2::Record::RepresentedCountry> object for the country
 represented by the requested IP address. The represented country may differ
 from the C<country> for things like military bases or embassies.
 
-=head2 $omni->subdivisions()
+=head2 $city_isp_org->subdivisions()
 
 Returns an array of L<GeoIP2::Record::Subdvision> objects representing the
 country subdivisions for the requested IP address. The number and type of
@@ -112,7 +120,7 @@ for Minneapolis in the United States would have a single object for Minnesota.
 If the response did not contain any subdivisions, this method returns an empty
 list.
 
-=head2 $omni->most_specific_subdivision()
+=head2 $city_isp_org->most_specific_subdivision()
 
 Returns a single L<GeoIP2::Record::Subdivision> object representing the most
 specific subdivision returned.
@@ -127,7 +135,7 @@ request IP address.
 
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>
+Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
