@@ -1,6 +1,6 @@
 package GeoIP2::Record::RepresentedCountry;
 {
-  $GeoIP2::Record::RepresentedCountry::VERSION = '0.0200';
+  $GeoIP2::Record::RepresentedCountry::VERSION = '0.0300';
 }
 
 use strict;
@@ -32,7 +32,7 @@ GeoIP2::Record::RepresentedCountry - Contains data for the represented country r
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,7 @@ This attribute is returned by all end points.
 
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>
+Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
