@@ -1,6 +1,6 @@
 package GeoIP2::Record::Subdivision;
 {
-  $GeoIP2::Record::Subdivision::VERSION = '0.0200';
+  $GeoIP2::Record::Subdivision::VERSION = '0.0300';
 }
 
 use strict;
@@ -44,7 +44,7 @@ GeoIP2::Record::Subdivision - Contains data for the subdivision record associate
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -116,7 +116,7 @@ This attribute is returned by all end points except the Country end point.
 
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>
+Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
