@@ -1,6 +1,6 @@
 package GeoIP2::Role::Model;
 {
-  $GeoIP2::Role::Model::VERSION = '0.0200';
+  $GeoIP2::Role::Model::VERSION = '0.0300';
 }
 
 use strict;
@@ -10,6 +10,8 @@ use GeoIP2::Record::City;
 use GeoIP2::Record::Continent;
 use GeoIP2::Record::Country;
 use GeoIP2::Record::Location;
+use GeoIP2::Record::MaxMind;
+use GeoIP2::Record::Postal;
 use GeoIP2::Record::RepresentedCountry;
 use GeoIP2::Record::Traits;
 use GeoIP2::Types qw( ArrayRef HashRef );
@@ -69,6 +71,20 @@ sub _define_attributes_for_keys {
     }
 }
 
+sub _all_record_names {
+    return qw(
+        city
+        continent
+        country
+        location
+        maxmind
+        postal
+        registered_country
+        represented_country
+        traits
+    );
+}
+
 around BUILDARGS => sub {
     my $orig = shift;
     my $self = shift;
@@ -94,16 +110,19 @@ sub _build_record {
         ->new( %{$raw}, languages => $self->languages() );
 }
 
-sub _record_class_for_key {
-    my $self = shift;
-    my $key  = shift;
+{
+    my %key_to_class = (
+        maxmind             => 'MaxMind',
+        registered_country  => 'Country',
+        represented_country => 'RepresentedCountry',
+    );
 
-    return 'GeoIP2::Record::Country' if $key eq 'registered_country';
+    sub _record_class_for_key {
+        my $self = shift;
+        my $key  = shift;
 
-    return 'GeoIP2::Record::RepresentedCountry'
-        if $key eq 'represented_country';
-
-    return 'GeoIP2::Record::' . ucfirst $key;
+        return 'GeoIP2::Record::' . ( $key_to_class{$key} || ucfirst $key );
+    }
 }
 
 1;
